"""
Main interface for codepipeline service client

Usage::

    import boto3
    from mypy_boto3.codepipeline import CodePipelineClient

    session = boto3.Session()

    client: CodePipelineClient = boto3.client("codepipeline")
    session_client: CodePipelineClient = session.client("codepipeline")
"""
# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
import sys
from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
from botocore.exceptions import ClientError as Boto3ClientError
from mypy_boto3_codepipeline.paginator import (
    ListActionExecutionsPaginator,
    ListActionTypesPaginator,
    ListPipelineExecutionsPaginator,
    ListPipelinesPaginator,
    ListTagsForResourcePaginator,
    ListWebhooksPaginator,
)
from mypy_boto3_codepipeline.type_defs import (
    AcknowledgeJobOutputTypeDef,
    AcknowledgeThirdPartyJobOutputTypeDef,
    ActionConfigurationPropertyTypeDef,
    ActionExecutionFilterTypeDef,
    ActionRevisionTypeDef,
    ActionTypeIdTypeDef,
    ActionTypeSettingsTypeDef,
    ApprovalResultTypeDef,
    ArtifactDetailsTypeDef,
    CreateCustomActionTypeOutputTypeDef,
    CreatePipelineOutputTypeDef,
    CurrentRevisionTypeDef,
    ExecutionDetailsTypeDef,
    FailureDetailsTypeDef,
    GetJobDetailsOutputTypeDef,
    GetPipelineExecutionOutputTypeDef,
    GetPipelineOutputTypeDef,
    GetPipelineStateOutputTypeDef,
    GetThirdPartyJobDetailsOutputTypeDef,
    ListActionExecutionsOutputTypeDef,
    ListActionTypesOutputTypeDef,
    ListPipelineExecutionsOutputTypeDef,
    ListPipelinesOutputTypeDef,
    ListTagsForResourceOutputTypeDef,
    ListWebhooksOutputTypeDef,
    PipelineDeclarationTypeDef,
    PollForJobsOutputTypeDef,
    PollForThirdPartyJobsOutputTypeDef,
    PutActionRevisionOutputTypeDef,
    PutApprovalResultOutputTypeDef,
    PutWebhookOutputTypeDef,
    RetryStageExecutionOutputTypeDef,
    StartPipelineExecutionOutputTypeDef,
    StopPipelineExecutionOutputTypeDef,
    TagTypeDef,
    UpdatePipelineOutputTypeDef,
    WebhookDefinitionTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("CodePipelineClient",)


class Exceptions:
    ActionNotFoundException: Type[Boto3ClientError]
    ActionTypeNotFoundException: Type[Boto3ClientError]
    ApprovalAlreadyCompletedException: Type[Boto3ClientError]
    ClientError: Type[Boto3ClientError]
    ConcurrentModificationException: Type[Boto3ClientError]
    DuplicatedStopRequestException: Type[Boto3ClientError]
    InvalidActionDeclarationException: Type[Boto3ClientError]
    InvalidApprovalTokenException: Type[Boto3ClientError]
    InvalidArnException: Type[Boto3ClientError]
    InvalidBlockerDeclarationException: Type[Boto3ClientError]
    InvalidClientTokenException: Type[Boto3ClientError]
    InvalidJobException: Type[Boto3ClientError]
    InvalidJobStateException: Type[Boto3ClientError]
    InvalidNextTokenException: Type[Boto3ClientError]
    InvalidNonceException: Type[Boto3ClientError]
    InvalidStageDeclarationException: Type[Boto3ClientError]
    InvalidStructureException: Type[Boto3ClientError]
    InvalidTagsException: Type[Boto3ClientError]
    InvalidWebhookAuthenticationParametersException: Type[Boto3ClientError]
    InvalidWebhookFilterPatternException: Type[Boto3ClientError]
    JobNotFoundException: Type[Boto3ClientError]
    LimitExceededException: Type[Boto3ClientError]
    NotLatestPipelineExecutionException: Type[Boto3ClientError]
    OutputVariablesSizeExceededException: Type[Boto3ClientError]
    PipelineExecutionNotFoundException: Type[Boto3ClientError]
    PipelineExecutionNotStoppableException: Type[Boto3ClientError]
    PipelineNameInUseException: Type[Boto3ClientError]
    PipelineNotFoundException: Type[Boto3ClientError]
    PipelineVersionNotFoundException: Type[Boto3ClientError]
    ResourceNotFoundException: Type[Boto3ClientError]
    StageNotFoundException: Type[Boto3ClientError]
    StageNotRetryableException: Type[Boto3ClientError]
    TooManyTagsException: Type[Boto3ClientError]
    ValidationException: Type[Boto3ClientError]
    WebhookNotFoundException: Type[Boto3ClientError]


class CodePipelineClient:
    """
    [CodePipeline.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client)
    """

    exceptions: Exceptions

    def acknowledge_job(self, jobId: str, nonce: str) -> AcknowledgeJobOutputTypeDef:
        """
        [Client.acknowledge_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
        """

    def acknowledge_third_party_job(
        self, jobId: str, nonce: str, clientToken: str
    ) -> AcknowledgeThirdPartyJobOutputTypeDef:
        """
        [Client.acknowledge_third_party_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
        """

    def create_custom_action_type(
        self,
        category: Literal["Source", "Build", "Deploy", "Test", "Invoke", "Approval"],
        provider: str,
        version: str,
        inputArtifactDetails: ArtifactDetailsTypeDef,
        outputArtifactDetails: ArtifactDetailsTypeDef,
        settings: ActionTypeSettingsTypeDef = None,
        configurationProperties: List[ActionConfigurationPropertyTypeDef] = None,
        tags: List[TagTypeDef] = None,
    ) -> CreateCustomActionTypeOutputTypeDef:
        """
        [Client.create_custom_action_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
        """

    def create_pipeline(
        self, pipeline: PipelineDeclarationTypeDef, tags: List[TagTypeDef] = None
    ) -> CreatePipelineOutputTypeDef:
        """
        [Client.create_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
        """

    def delete_custom_action_type(
        self,
        category: Literal["Source", "Build", "Deploy", "Test", "Invoke", "Approval"],
        provider: str,
        version: str,
    ) -> None:
        """
        [Client.delete_custom_action_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
        """

    def delete_pipeline(self, name: str) -> None:
        """
        [Client.delete_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
        """

    def delete_webhook(self, name: str) -> Dict[str, Any]:
        """
        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
        """

    def deregister_webhook_with_third_party(self, webhookName: str = None) -> Dict[str, Any]:
        """
        [Client.deregister_webhook_with_third_party documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
        """

    def disable_stage_transition(
        self,
        pipelineName: str,
        stageName: str,
        transitionType: Literal["Inbound", "Outbound"],
        reason: str,
    ) -> None:
        """
        [Client.disable_stage_transition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
        """

    def enable_stage_transition(
        self, pipelineName: str, stageName: str, transitionType: Literal["Inbound", "Outbound"]
    ) -> None:
        """
        [Client.enable_stage_transition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
        """

    def get_job_details(self, jobId: str) -> GetJobDetailsOutputTypeDef:
        """
        [Client.get_job_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
        """

    def get_pipeline(self, name: str, version: int = None) -> GetPipelineOutputTypeDef:
        """
        [Client.get_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
        """

    def get_pipeline_execution(
        self, pipelineName: str, pipelineExecutionId: str
    ) -> GetPipelineExecutionOutputTypeDef:
        """
        [Client.get_pipeline_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
        """

    def get_pipeline_state(self, name: str) -> GetPipelineStateOutputTypeDef:
        """
        [Client.get_pipeline_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
        """

    def get_third_party_job_details(
        self, jobId: str, clientToken: str
    ) -> GetThirdPartyJobDetailsOutputTypeDef:
        """
        [Client.get_third_party_job_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
        """

    def list_action_executions(
        self,
        pipelineName: str,
        filter: ActionExecutionFilterTypeDef = None,
        maxResults: int = None,
        nextToken: str = None,
    ) -> ListActionExecutionsOutputTypeDef:
        """
        [Client.list_action_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
        """

    def list_action_types(
        self,
        actionOwnerFilter: Literal["AWS", "ThirdParty", "Custom"] = None,
        nextToken: str = None,
    ) -> ListActionTypesOutputTypeDef:
        """
        [Client.list_action_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
        """

    def list_pipeline_executions(
        self, pipelineName: str, maxResults: int = None, nextToken: str = None
    ) -> ListPipelineExecutionsOutputTypeDef:
        """
        [Client.list_pipeline_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
        """

    def list_pipelines(self, nextToken: str = None) -> ListPipelinesOutputTypeDef:
        """
        [Client.list_pipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
        """

    def list_tags_for_resource(
        self, resourceArn: str, nextToken: str = None, maxResults: int = None
    ) -> ListTagsForResourceOutputTypeDef:
        """
        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
        """

    def list_webhooks(
        self, NextToken: str = None, MaxResults: int = None
    ) -> ListWebhooksOutputTypeDef:
        """
        [Client.list_webhooks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
        """

    def poll_for_jobs(
        self,
        actionTypeId: ActionTypeIdTypeDef,
        maxBatchSize: int = None,
        queryParam: Dict[str, str] = None,
    ) -> PollForJobsOutputTypeDef:
        """
        [Client.poll_for_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
        """

    def poll_for_third_party_jobs(
        self, actionTypeId: ActionTypeIdTypeDef, maxBatchSize: int = None
    ) -> PollForThirdPartyJobsOutputTypeDef:
        """
        [Client.poll_for_third_party_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
        """

    def put_action_revision(
        self,
        pipelineName: str,
        stageName: str,
        actionName: str,
        actionRevision: ActionRevisionTypeDef,
    ) -> PutActionRevisionOutputTypeDef:
        """
        [Client.put_action_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
        """

    def put_approval_result(
        self,
        pipelineName: str,
        stageName: str,
        actionName: str,
        result: ApprovalResultTypeDef,
        token: str,
    ) -> PutApprovalResultOutputTypeDef:
        """
        [Client.put_approval_result documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
        """

    def put_job_failure_result(self, jobId: str, failureDetails: FailureDetailsTypeDef) -> None:
        """
        [Client.put_job_failure_result documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
        """

    def put_job_success_result(
        self,
        jobId: str,
        currentRevision: CurrentRevisionTypeDef = None,
        continuationToken: str = None,
        executionDetails: ExecutionDetailsTypeDef = None,
        outputVariables: Dict[str, str] = None,
    ) -> None:
        """
        [Client.put_job_success_result documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
        """

    def put_third_party_job_failure_result(
        self, jobId: str, clientToken: str, failureDetails: FailureDetailsTypeDef
    ) -> None:
        """
        [Client.put_third_party_job_failure_result documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
        """

    def put_third_party_job_success_result(
        self,
        jobId: str,
        clientToken: str,
        currentRevision: CurrentRevisionTypeDef = None,
        continuationToken: str = None,
        executionDetails: ExecutionDetailsTypeDef = None,
    ) -> None:
        """
        [Client.put_third_party_job_success_result documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
        """

    def put_webhook(
        self, webhook: WebhookDefinitionTypeDef, tags: List[TagTypeDef] = None
    ) -> PutWebhookOutputTypeDef:
        """
        [Client.put_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
        """

    def register_webhook_with_third_party(self, webhookName: str = None) -> Dict[str, Any]:
        """
        [Client.register_webhook_with_third_party documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
        """

    def retry_stage_execution(
        self,
        pipelineName: str,
        stageName: str,
        pipelineExecutionId: str,
        retryMode: Literal["FAILED_ACTIONS"],
    ) -> RetryStageExecutionOutputTypeDef:
        """
        [Client.retry_stage_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
        """

    def start_pipeline_execution(
        self, name: str, clientRequestToken: str = None
    ) -> StartPipelineExecutionOutputTypeDef:
        """
        [Client.start_pipeline_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
        """

    def stop_pipeline_execution(
        self, pipelineName: str, pipelineExecutionId: str, abandon: bool = None, reason: str = None
    ) -> StopPipelineExecutionOutputTypeDef:
        """
        [Client.stop_pipeline_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
        """

    def tag_resource(self, resourceArn: str, tags: List[TagTypeDef]) -> Dict[str, Any]:
        """
        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
        """

    def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
        """
        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
        """

    def update_pipeline(self, pipeline: PipelineDeclarationTypeDef) -> UpdatePipelineOutputTypeDef:
        """
        [Client.update_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_action_executions"]
    ) -> ListActionExecutionsPaginator:
        """
        [Paginator.ListActionExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_action_types"]
    ) -> ListActionTypesPaginator:
        """
        [Paginator.ListActionTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_pipeline_executions"]
    ) -> ListPipelineExecutionsPaginator:
        """
        [Paginator.ListPipelineExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
        """

    @overload
    def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
        """
        [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_tags_for_resource"]
    ) -> ListTagsForResourcePaginator:
        """
        [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
        """

    @overload
    def get_paginator(self, operation_name: Literal["list_webhooks"]) -> ListWebhooksPaginator:
        """
        [Paginator.ListWebhooks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
        """



"""
Main interface for codepipeline service type definitions.

Usage::

    from mypy_boto3.codepipeline.type_defs import AcknowledgeJobOutputTypeDef

    data: AcknowledgeJobOutputTypeDef = {...}
"""
from datetime import datetime
import sys
from typing import Dict, List

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "AcknowledgeJobOutputTypeDef",
    "AcknowledgeThirdPartyJobOutputTypeDef",
    "ActionConfigurationPropertyTypeDef",
    "ActionExecutionFilterTypeDef",
    "ActionRevisionTypeDef",
    "ActionTypeIdTypeDef",
    "ActionTypeSettingsTypeDef",
    "ApprovalResultTypeDef",
    "ArtifactDetailsTypeDef",
    "ActionTypeTypeDef",
    "TagTypeDef",
    "CreateCustomActionTypeOutputTypeDef",
    "EncryptionKeyTypeDef",
    "ArtifactStoreTypeDef",
    "InputArtifactTypeDef",
    "OutputArtifactTypeDef",
    "ActionDeclarationTypeDef",
    "BlockerDeclarationTypeDef",
    "StageDeclarationTypeDef",
    "PipelineDeclarationTypeDef",
    "CreatePipelineOutputTypeDef",
    "CurrentRevisionTypeDef",
    "ExecutionDetailsTypeDef",
    "FailureDetailsTypeDef",
    "AWSSessionCredentialsTypeDef",
    "ActionConfigurationTypeDef",
    "S3ArtifactLocationTypeDef",
    "ArtifactLocationTypeDef",
    "ArtifactTypeDef",
    "ActionContextTypeDef",
    "StageContextTypeDef",
    "PipelineContextTypeDef",
    "JobDataTypeDef",
    "JobDetailsTypeDef",
    "GetJobDetailsOutputTypeDef",
    "ArtifactRevisionTypeDef",
    "PipelineExecutionTypeDef",
    "GetPipelineExecutionOutputTypeDef",
    "PipelineMetadataTypeDef",
    "GetPipelineOutputTypeDef",
    "ErrorDetailsTypeDef",
    "ActionExecutionTypeDef",
    "ActionStateTypeDef",
    "StageExecutionTypeDef",
    "TransitionStateTypeDef",
    "StageStateTypeDef",
    "GetPipelineStateOutputTypeDef",
    "ThirdPartyJobDataTypeDef",
    "ThirdPartyJobDetailsTypeDef",
    "GetThirdPartyJobDetailsOutputTypeDef",
    "S3LocationTypeDef",
    "ArtifactDetailTypeDef",
    "ActionExecutionInputTypeDef",
    "ActionExecutionResultTypeDef",
    "ActionExecutionOutputTypeDef",
    "ActionExecutionDetailTypeDef",
    "ListActionExecutionsOutputTypeDef",
    "ListActionTypesOutputTypeDef",
    "ExecutionTriggerTypeDef",
    "SourceRevisionTypeDef",
    "StopExecutionTriggerTypeDef",
    "PipelineExecutionSummaryTypeDef",
    "ListPipelineExecutionsOutputTypeDef",
    "PipelineSummaryTypeDef",
    "ListPipelinesOutputTypeDef",
    "ListTagsForResourceOutputTypeDef",
    "WebhookAuthConfigurationTypeDef",
    "WebhookFilterRuleTypeDef",
    "WebhookDefinitionTypeDef",
    "ListWebhookItemTypeDef",
    "ListWebhooksOutputTypeDef",
    "PaginatorConfigTypeDef",
    "JobTypeDef",
    "PollForJobsOutputTypeDef",
    "ThirdPartyJobTypeDef",
    "PollForThirdPartyJobsOutputTypeDef",
    "PutActionRevisionOutputTypeDef",
    "PutApprovalResultOutputTypeDef",
    "PutWebhookOutputTypeDef",
    "RetryStageExecutionOutputTypeDef",
    "StartPipelineExecutionOutputTypeDef",
    "StopPipelineExecutionOutputTypeDef",
    "UpdatePipelineOutputTypeDef",
)

AcknowledgeJobOutputTypeDef = TypedDict(
    "AcknowledgeJobOutputTypeDef",
    {
        "status": Literal[
            "Created", "Queued", "Dispatched", "InProgress", "TimedOut", "Succeeded", "Failed"
        ]
    },
    total=False,
)

AcknowledgeThirdPartyJobOutputTypeDef = TypedDict(
    "AcknowledgeThirdPartyJobOutputTypeDef",
    {
        "status": Literal[
            "Created", "Queued", "Dispatched", "InProgress", "TimedOut", "Succeeded", "Failed"
        ]
    },
    total=False,
)

_RequiredActionConfigurationPropertyTypeDef = TypedDict(
    "_RequiredActionConfigurationPropertyTypeDef",
    {"name": str, "required": bool, "key": bool, "secret": bool},
)
_OptionalActionConfigurationPropertyTypeDef = TypedDict(
    "_OptionalActionConfigurationPropertyTypeDef",
    {"queryable": bool, "description": str, "type": Literal["String", "Number", "Boolean"]},
    total=False,
)


class ActionConfigurationPropertyTypeDef(
    _RequiredActionConfigurationPropertyTypeDef, _OptionalActionConfigurationPropertyTypeDef
):
    pass


ActionExecutionFilterTypeDef = TypedDict(
    "ActionExecutionFilterTypeDef", {"pipelineExecutionId": str}, total=False
)

ActionRevisionTypeDef = TypedDict(
    "ActionRevisionTypeDef", {"revisionId": str, "revisionChangeId": str, "created": datetime}
)

ActionTypeIdTypeDef = TypedDict(
    "ActionTypeIdTypeDef",
    {
        "category": Literal["Source", "Build", "Deploy", "Test", "Invoke", "Approval"],
        "owner": Literal["AWS", "ThirdParty", "Custom"],
        "provider": str,
        "version": str,
    },
)

ActionTypeSettingsTypeDef = TypedDict(
    "ActionTypeSettingsTypeDef",
    {
        "thirdPartyConfigurationUrl": str,
        "entityUrlTemplate": str,
        "executionUrlTemplate": str,
        "revisionUrlTemplate": str,
    },
    total=False,
)

ApprovalResultTypeDef = TypedDict(
    "ApprovalResultTypeDef", {"summary": str, "status": Literal["Approved", "Rejected"]}
)

ArtifactDetailsTypeDef = TypedDict(
    "ArtifactDetailsTypeDef", {"minimumCount": int, "maximumCount": int}
)

_RequiredActionTypeTypeDef = TypedDict(
    "_RequiredActionTypeTypeDef",
    {
        "id": ActionTypeIdTypeDef,
        "inputArtifactDetails": ArtifactDetailsTypeDef,
        "outputArtifactDetails": ArtifactDetailsTypeDef,
    },
)
_OptionalActionTypeTypeDef = TypedDict(
    "_OptionalActionTypeTypeDef",
    {
        "settings": ActionTypeSettingsTypeDef,
        "actionConfigurationProperties": List[ActionConfigurationPropertyTypeDef],
    },
    total=False,
)


class ActionTypeTypeDef(_RequiredActionTypeTypeDef, _OptionalActionTypeTypeDef):
    pass


TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str})

_RequiredCreateCustomActionTypeOutputTypeDef = TypedDict(
    "_RequiredCreateCustomActionTypeOutputTypeDef", {"actionType": ActionTypeTypeDef}
)
_OptionalCreateCustomActionTypeOutputTypeDef = TypedDict(
    "_OptionalCreateCustomActionTypeOutputTypeDef", {"tags": List[TagTypeDef]}, total=False
)


class CreateCustomActionTypeOutputTypeDef(
    _RequiredCreateCustomActionTypeOutputTypeDef, _OptionalCreateCustomActionTypeOutputTypeDef
):
    pass


EncryptionKeyTypeDef = TypedDict("EncryptionKeyTypeDef", {"id": str, "type": Literal["KMS"]})

_RequiredArtifactStoreTypeDef = TypedDict(
    "_RequiredArtifactStoreTypeDef", {"type": Literal["S3"], "location": str}
)
_OptionalArtifactStoreTypeDef = TypedDict(
    "_OptionalArtifactStoreTypeDef", {"encryptionKey": EncryptionKeyTypeDef}, total=False
)


class ArtifactStoreTypeDef(_RequiredArtifactStoreTypeDef, _OptionalArtifactStoreTypeDef):
    pass


InputArtifactTypeDef = TypedDict("InputArtifactTypeDef", {"name": str})

OutputArtifactTypeDef = TypedDict("OutputArtifactTypeDef", {"name": str})

_RequiredActionDeclarationTypeDef = TypedDict(
    "_RequiredActionDeclarationTypeDef", {"name": str, "actionTypeId": ActionTypeIdTypeDef}
)
_OptionalActionDeclarationTypeDef = TypedDict(
    "_OptionalActionDeclarationTypeDef",
    {
        "runOrder": int,
        "configuration": Dict[str, str],
        "outputArtifacts": List[OutputArtifactTypeDef],
        "inputArtifacts": List[InputArtifactTypeDef],
        "roleArn": str,
        "region": str,
        "namespace": str,
    },
    total=False,
)


class ActionDeclarationTypeDef(
    _RequiredActionDeclarationTypeDef, _OptionalActionDeclarationTypeDef
):
    pass


BlockerDeclarationTypeDef = TypedDict(
    "BlockerDeclarationTypeDef", {"name": str, "type": Literal["Schedule"]}
)

_RequiredStageDeclarationTypeDef = TypedDict(
    "_RequiredStageDeclarationTypeDef", {"name": str, "actions": List[ActionDeclarationTypeDef]}
)
_OptionalStageDeclarationTypeDef = TypedDict(
    "_OptionalStageDeclarationTypeDef", {"blockers": List[BlockerDeclarationTypeDef]}, total=False
)


class StageDeclarationTypeDef(_RequiredStageDeclarationTypeDef, _OptionalStageDeclarationTypeDef):
    pass


_RequiredPipelineDeclarationTypeDef = TypedDict(
    "_RequiredPipelineDeclarationTypeDef",
    {"name": str, "roleArn": str, "stages": List[StageDeclarationTypeDef]},
)
_OptionalPipelineDeclarationTypeDef = TypedDict(
    "_OptionalPipelineDeclarationTypeDef",
    {
        "artifactStore": ArtifactStoreTypeDef,
        "artifactStores": Dict[str, ArtifactStoreTypeDef],
        "version": int,
    },
    total=False,
)


class PipelineDeclarationTypeDef(
    _RequiredPipelineDeclarationTypeDef, _OptionalPipelineDeclarationTypeDef
):
    pass


CreatePipelineOutputTypeDef = TypedDict(
    "CreatePipelineOutputTypeDef",
    {"pipeline": PipelineDeclarationTypeDef, "tags": List[TagTypeDef]},
    total=False,
)

_RequiredCurrentRevisionTypeDef = TypedDict(
    "_RequiredCurrentRevisionTypeDef", {"revision": str, "changeIdentifier": str}
)
_OptionalCurrentRevisionTypeDef = TypedDict(
    "_OptionalCurrentRevisionTypeDef", {"created": datetime, "revisionSummary": str}, total=False
)


class CurrentRevisionTypeDef(_RequiredCurrentRevisionTypeDef, _OptionalCurrentRevisionTypeDef):
    pass


ExecutionDetailsTypeDef = TypedDict(
    "ExecutionDetailsTypeDef",
    {"summary": str, "externalExecutionId": str, "percentComplete": int},
    total=False,
)

_RequiredFailureDetailsTypeDef = TypedDict(
    "_RequiredFailureDetailsTypeDef",
    {
        "type": Literal[
            "JobFailed",
            "ConfigurationError",
            "PermissionError",
            "RevisionOutOfSync",
            "RevisionUnavailable",
            "SystemUnavailable",
        ],
        "message": str,
    },
)
_OptionalFailureDetailsTypeDef = TypedDict(
    "_OptionalFailureDetailsTypeDef", {"externalExecutionId": str}, total=False
)


class FailureDetailsTypeDef(_RequiredFailureDetailsTypeDef, _OptionalFailureDetailsTypeDef):
    pass


AWSSessionCredentialsTypeDef = TypedDict(
    "AWSSessionCredentialsTypeDef",
    {"accessKeyId": str, "secretAccessKey": str, "sessionToken": str},
)

ActionConfigurationTypeDef = TypedDict(
    "ActionConfigurationTypeDef", {"configuration": Dict[str, str]}, total=False
)

S3ArtifactLocationTypeDef = TypedDict(
    "S3ArtifactLocationTypeDef", {"bucketName": str, "objectKey": str}
)

ArtifactLocationTypeDef = TypedDict(
    "ArtifactLocationTypeDef",
    {"type": Literal["S3"], "s3Location": S3ArtifactLocationTypeDef},
    total=False,
)

ArtifactTypeDef = TypedDict(
    "ArtifactTypeDef",
    {"name": str, "revision": str, "location": ArtifactLocationTypeDef},
    total=False,
)

ActionContextTypeDef = TypedDict(
    "ActionContextTypeDef", {"name": str, "actionExecutionId": str}, total=False
)

StageContextTypeDef = TypedDict("StageContextTypeDef", {"name": str}, total=False)

PipelineContextTypeDef = TypedDict(
    "PipelineContextTypeDef",
    {
        "pipelineName": str,
        "stage": StageContextTypeDef,
        "action": ActionContextTypeDef,
        "pipelineArn": str,
        "pipelineExecutionId": str,
    },
    total=False,
)

JobDataTypeDef = TypedDict(
    "JobDataTypeDef",
    {
        "actionTypeId": ActionTypeIdTypeDef,
        "actionConfiguration": ActionConfigurationTypeDef,
        "pipelineContext": PipelineContextTypeDef,
        "inputArtifacts": List[ArtifactTypeDef],
        "outputArtifacts": List[ArtifactTypeDef],
        "artifactCredentials": AWSSessionCredentialsTypeDef,
        "continuationToken": str,
        "encryptionKey": EncryptionKeyTypeDef,
    },
    total=False,
)

JobDetailsTypeDef = TypedDict(
    "JobDetailsTypeDef", {"id": str, "data": JobDataTypeDef, "accountId": str}, total=False
)

GetJobDetailsOutputTypeDef = TypedDict(
    "GetJobDetailsOutputTypeDef", {"jobDetails": JobDetailsTypeDef}, total=False
)

ArtifactRevisionTypeDef = TypedDict(
    "ArtifactRevisionTypeDef",
    {
        "name": str,
        "revisionId": str,
        "revisionChangeIdentifier": str,
        "revisionSummary": str,
        "created": datetime,
        "revisionUrl": str,
    },
    total=False,
)

PipelineExecutionTypeDef = TypedDict(
    "PipelineExecutionTypeDef",
    {
        "pipelineName": str,
        "pipelineVersion": int,
        "pipelineExecutionId": str,
        "status": Literal["InProgress", "Stopped", "Stopping", "Succeeded", "Superseded", "Failed"],
        "artifactRevisions": List[ArtifactRevisionTypeDef],
    },
    total=False,
)

GetPipelineExecutionOutputTypeDef = TypedDict(
    "GetPipelineExecutionOutputTypeDef",
    {"pipelineExecution": PipelineExecutionTypeDef},
    total=False,
)

PipelineMetadataTypeDef = TypedDict(
    "PipelineMetadataTypeDef",
    {"pipelineArn": str, "created": datetime, "updated": datetime},
    total=False,
)

GetPipelineOutputTypeDef = TypedDict(
    "GetPipelineOutputTypeDef",
    {"pipeline": PipelineDeclarationTypeDef, "metadata": PipelineMetadataTypeDef},
    total=False,
)

ErrorDetailsTypeDef = TypedDict("ErrorDetailsTypeDef", {"code": str, "message": str}, total=False)

ActionExecutionTypeDef = TypedDict(
    "ActionExecutionTypeDef",
    {
        "status": Literal["InProgress", "Abandoned", "Succeeded", "Failed"],
        "summary": str,
        "lastStatusChange": datetime,
        "token": str,
        "lastUpdatedBy": str,
        "externalExecutionId": str,
        "externalExecutionUrl": str,
        "percentComplete": int,
        "errorDetails": ErrorDetailsTypeDef,
    },
    total=False,
)

ActionStateTypeDef = TypedDict(
    "ActionStateTypeDef",
    {
        "actionName": str,
        "currentRevision": ActionRevisionTypeDef,
        "latestExecution": ActionExecutionTypeDef,
        "entityUrl": str,
        "revisionUrl": str,
    },
    total=False,
)

StageExecutionTypeDef = TypedDict(
    "StageExecutionTypeDef",
    {
        "pipelineExecutionId": str,
        "status": Literal["InProgress", "Failed", "Stopped", "Stopping", "Succeeded"],
    },
)

TransitionStateTypeDef = TypedDict(
    "TransitionStateTypeDef",
    {"enabled": bool, "lastChangedBy": str, "lastChangedAt": datetime, "disabledReason": str},
    total=False,
)

StageStateTypeDef = TypedDict(
    "StageStateTypeDef",
    {
        "stageName": str,
        "inboundTransitionState": TransitionStateTypeDef,
        "actionStates": List[ActionStateTypeDef],
        "latestExecution": StageExecutionTypeDef,
    },
    total=False,
)

GetPipelineStateOutputTypeDef = TypedDict(
    "GetPipelineStateOutputTypeDef",
    {
        "pipelineName": str,
        "pipelineVersion": int,
        "stageStates": List[StageStateTypeDef],
        "created": datetime,
        "updated": datetime,
    },
    total=False,
)

ThirdPartyJobDataTypeDef = TypedDict(
    "ThirdPartyJobDataTypeDef",
    {
        "actionTypeId": ActionTypeIdTypeDef,
        "actionConfiguration": ActionConfigurationTypeDef,
        "pipelineContext": PipelineContextTypeDef,
        "inputArtifacts": List[ArtifactTypeDef],
        "outputArtifacts": List[ArtifactTypeDef],
        "artifactCredentials": AWSSessionCredentialsTypeDef,
        "continuationToken": str,
        "encryptionKey": EncryptionKeyTypeDef,
    },
    total=False,
)

ThirdPartyJobDetailsTypeDef = TypedDict(
    "ThirdPartyJobDetailsTypeDef",
    {"id": str, "data": ThirdPartyJobDataTypeDef, "nonce": str},
    total=False,
)

GetThirdPartyJobDetailsOutputTypeDef = TypedDict(
    "GetThirdPartyJobDetailsOutputTypeDef", {"jobDetails": ThirdPartyJobDetailsTypeDef}, total=False
)

S3LocationTypeDef = TypedDict("S3LocationTypeDef", {"bucket": str, "key": str}, total=False)

ArtifactDetailTypeDef = TypedDict(
    "ArtifactDetailTypeDef", {"name": str, "s3location": S3LocationTypeDef}, total=False
)

ActionExecutionInputTypeDef = TypedDict(
    "ActionExecutionInputTypeDef",
    {
        "actionTypeId": ActionTypeIdTypeDef,
        "configuration": Dict[str, str],
        "resolvedConfiguration": Dict[str, str],
        "roleArn": str,
        "region": str,
        "inputArtifacts": List[ArtifactDetailTypeDef],
        "namespace": str,
    },
    total=False,
)

ActionExecutionResultTypeDef = TypedDict(
    "ActionExecutionResultTypeDef",
    {"externalExecutionId": str, "externalExecutionSummary": str, "externalExecutionUrl": str},
    total=False,
)

ActionExecutionOutputTypeDef = TypedDict(
    "ActionExecutionOutputTypeDef",
    {
        "outputArtifacts": List[ArtifactDetailTypeDef],
        "executionResult": ActionExecutionResultTypeDef,
        "outputVariables": Dict[str, str],
    },
    total=False,
)

ActionExecutionDetailTypeDef = TypedDict(
    "ActionExecutionDetailTypeDef",
    {
        "pipelineExecutionId": str,
        "actionExecutionId": str,
        "pipelineVersion": int,
        "stageName": str,
        "actionName": str,
        "startTime": datetime,
        "lastUpdateTime": datetime,
        "status": Literal["InProgress", "Abandoned", "Succeeded", "Failed"],
        "input": ActionExecutionInputTypeDef,
        "output": ActionExecutionOutputTypeDef,
    },
    total=False,
)

ListActionExecutionsOutputTypeDef = TypedDict(
    "ListActionExecutionsOutputTypeDef",
    {"actionExecutionDetails": List[ActionExecutionDetailTypeDef], "nextToken": str},
    total=False,
)

_RequiredListActionTypesOutputTypeDef = TypedDict(
    "_RequiredListActionTypesOutputTypeDef", {"actionTypes": List[ActionTypeTypeDef]}
)
_OptionalListActionTypesOutputTypeDef = TypedDict(
    "_OptionalListActionTypesOutputTypeDef", {"nextToken": str}, total=False
)


class ListActionTypesOutputTypeDef(
    _RequiredListActionTypesOutputTypeDef, _OptionalListActionTypesOutputTypeDef
):
    pass


ExecutionTriggerTypeDef = TypedDict(
    "ExecutionTriggerTypeDef",
    {
        "triggerType": Literal[
            "CreatePipeline",
            "StartPipelineExecution",
            "PollForSourceChanges",
            "Webhook",
            "CloudWatchEvent",
            "PutActionRevision",
        ],
        "triggerDetail": str,
    },
    total=False,
)

_RequiredSourceRevisionTypeDef = TypedDict("_RequiredSourceRevisionTypeDef", {"actionName": str})
_OptionalSourceRevisionTypeDef = TypedDict(
    "_OptionalSourceRevisionTypeDef",
    {"revisionId": str, "revisionSummary": str, "revisionUrl": str},
    total=False,
)


class SourceRevisionTypeDef(_RequiredSourceRevisionTypeDef, _OptionalSourceRevisionTypeDef):
    pass


StopExecutionTriggerTypeDef = TypedDict("StopExecutionTriggerTypeDef", {"reason": str}, total=False)

PipelineExecutionSummaryTypeDef = TypedDict(
    "PipelineExecutionSummaryTypeDef",
    {
        "pipelineExecutionId": str,
        "status": Literal["InProgress", "Stopped", "Stopping", "Succeeded", "Superseded", "Failed"],
        "startTime": datetime,
        "lastUpdateTime": datetime,
        "sourceRevisions": List[SourceRevisionTypeDef],
        "trigger": ExecutionTriggerTypeDef,
        "stopTrigger": StopExecutionTriggerTypeDef,
    },
    total=False,
)

ListPipelineExecutionsOutputTypeDef = TypedDict(
    "ListPipelineExecutionsOutputTypeDef",
    {"pipelineExecutionSummaries": List[PipelineExecutionSummaryTypeDef], "nextToken": str},
    total=False,
)

PipelineSummaryTypeDef = TypedDict(
    "PipelineSummaryTypeDef",
    {"name": str, "version": int, "created": datetime, "updated": datetime},
    total=False,
)

ListPipelinesOutputTypeDef = TypedDict(
    "ListPipelinesOutputTypeDef",
    {"pipelines": List[PipelineSummaryTypeDef], "nextToken": str},
    total=False,
)

ListTagsForResourceOutputTypeDef = TypedDict(
    "ListTagsForResourceOutputTypeDef", {"tags": List[TagTypeDef], "nextToken": str}, total=False
)

WebhookAuthConfigurationTypeDef = TypedDict(
    "WebhookAuthConfigurationTypeDef", {"AllowedIPRange": str, "SecretToken": str}, total=False
)

_RequiredWebhookFilterRuleTypeDef = TypedDict(
    "_RequiredWebhookFilterRuleTypeDef", {"jsonPath": str}
)
_OptionalWebhookFilterRuleTypeDef = TypedDict(
    "_OptionalWebhookFilterRuleTypeDef", {"matchEquals": str}, total=False
)


class WebhookFilterRuleTypeDef(
    _RequiredWebhookFilterRuleTypeDef, _OptionalWebhookFilterRuleTypeDef
):
    pass


WebhookDefinitionTypeDef = TypedDict(
    "WebhookDefinitionTypeDef",
    {
        "name": str,
        "targetPipeline": str,
        "targetAction": str,
        "filters": List[WebhookFilterRuleTypeDef],
        "authentication": Literal["GITHUB_HMAC", "IP", "UNAUTHENTICATED"],
        "authenticationConfiguration": WebhookAuthConfigurationTypeDef,
    },
)

_RequiredListWebhookItemTypeDef = TypedDict(
    "_RequiredListWebhookItemTypeDef", {"definition": WebhookDefinitionTypeDef, "url": str}
)
_OptionalListWebhookItemTypeDef = TypedDict(
    "_OptionalListWebhookItemTypeDef",
    {
        "errorMessage": str,
        "errorCode": str,
        "lastTriggered": datetime,
        "arn": str,
        "tags": List[TagTypeDef],
    },
    total=False,
)


class ListWebhookItemTypeDef(_RequiredListWebhookItemTypeDef, _OptionalListWebhookItemTypeDef):
    pass


ListWebhooksOutputTypeDef = TypedDict(
    "ListWebhooksOutputTypeDef",
    {"webhooks": List[ListWebhookItemTypeDef], "NextToken": str},
    total=False,
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
)

JobTypeDef = TypedDict(
    "JobTypeDef", {"id": str, "data": JobDataTypeDef, "nonce": str, "accountId": str}, total=False
)

PollForJobsOutputTypeDef = TypedDict(
    "PollForJobsOutputTypeDef", {"jobs": List[JobTypeDef]}, total=False
)

ThirdPartyJobTypeDef = TypedDict(
    "ThirdPartyJobTypeDef", {"clientId": str, "jobId": str}, total=False
)

PollForThirdPartyJobsOutputTypeDef = TypedDict(
    "PollForThirdPartyJobsOutputTypeDef", {"jobs": List[ThirdPartyJobTypeDef]}, total=False
)

PutActionRevisionOutputTypeDef = TypedDict(
    "PutActionRevisionOutputTypeDef", {"newRevision": bool, "pipelineExecutionId": str}, total=False
)

PutApprovalResultOutputTypeDef = TypedDict(
    "PutApprovalResultOutputTypeDef", {"approvedAt": datetime}, total=False
)

PutWebhookOutputTypeDef = TypedDict(
    "PutWebhookOutputTypeDef", {"webhook": ListWebhookItemTypeDef}, total=False
)

RetryStageExecutionOutputTypeDef = TypedDict(
    "RetryStageExecutionOutputTypeDef", {"pipelineExecutionId": str}, total=False
)

StartPipelineExecutionOutputTypeDef = TypedDict(
    "StartPipelineExecutionOutputTypeDef", {"pipelineExecutionId": str}, total=False
)

StopPipelineExecutionOutputTypeDef = TypedDict(
    "StopPipelineExecutionOutputTypeDef", {"pipelineExecutionId": str}, total=False
)

UpdatePipelineOutputTypeDef = TypedDict(
    "UpdatePipelineOutputTypeDef", {"pipeline": PipelineDeclarationTypeDef}, total=False
)



"""
Main interface for codepipeline service client paginators.

Usage::

    import boto3
    from mypy_boto3.codepipeline import (
        ListActionExecutionsPaginator,
        ListActionTypesPaginator,
        ListPipelineExecutionsPaginator,
        ListPipelinesPaginator,
        ListTagsForResourcePaginator,
        ListWebhooksPaginator,
    )

    client: CodePipelineClient = boto3.client("codepipeline")

    list_action_executions_paginator: ListActionExecutionsPaginator = client.get_paginator("list_action_executions")
    list_action_types_paginator: ListActionTypesPaginator = client.get_paginator("list_action_types")
    list_pipeline_executions_paginator: ListPipelineExecutionsPaginator = client.get_paginator("list_pipeline_executions")
    list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
    list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
    list_webhooks_paginator: ListWebhooksPaginator = client.get_paginator("list_webhooks")
"""
# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
import sys
from typing import Iterator, TYPE_CHECKING
from botocore.paginate import Paginator as Boto3Paginator
from mypy_boto3_codepipeline.type_defs import (
    ActionExecutionFilterTypeDef,
    ListActionExecutionsOutputTypeDef,
    ListActionTypesOutputTypeDef,
    ListPipelineExecutionsOutputTypeDef,
    ListPipelinesOutputTypeDef,
    ListTagsForResourceOutputTypeDef,
    ListWebhooksOutputTypeDef,
    PaginatorConfigTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "ListActionExecutionsPaginator",
    "ListActionTypesPaginator",
    "ListPipelineExecutionsPaginator",
    "ListPipelinesPaginator",
    "ListTagsForResourcePaginator",
    "ListWebhooksPaginator",
)


class ListActionExecutionsPaginator(Boto3Paginator):
    """
    [Paginator.ListActionExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
    """

    def paginate(
        self,
        pipelineName: str,
        filter: ActionExecutionFilterTypeDef = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[ListActionExecutionsOutputTypeDef]:
        """
        [ListActionExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions.paginate)
        """


class ListActionTypesPaginator(Boto3Paginator):
    """
    [Paginator.ListActionTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
    """

    def paginate(
        self,
        actionOwnerFilter: Literal["AWS", "ThirdParty", "Custom"] = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[ListActionTypesOutputTypeDef]:
        """
        [ListActionTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes.paginate)
        """


class ListPipelineExecutionsPaginator(Boto3Paginator):
    """
    [Paginator.ListPipelineExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
    """

    def paginate(
        self, pipelineName: str, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListPipelineExecutionsOutputTypeDef]:
        """
        [ListPipelineExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions.paginate)
        """


class ListPipelinesPaginator(Boto3Paginator):
    """
    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
    """

    def paginate(
        self, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListPipelinesOutputTypeDef]:
        """
        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines.paginate)
        """


class ListTagsForResourcePaginator(Boto3Paginator):
    """
    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
    """

    def paginate(
        self, resourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListTagsForResourceOutputTypeDef]:
        """
        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource.paginate)
        """


class ListWebhooksPaginator(Boto3Paginator):
    """
    [Paginator.ListWebhooks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
    """

    def paginate(
        self, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListWebhooksOutputTypeDef]:
        """
        [ListWebhooks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.3/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks.paginate)
        """
